@@ -21,7 +21,11 @@ class AbstractFSClass(ABC):
         pass
 
     @abstractmethod
-    def file_remove(self, file_path, file_name):
+    def file_fd(self, file_path, file_name):
+        pass
+
+    @abstractmethod
+    def file_fd_bin(self, file_path, file_name):
         pass
 
     @abstractmethod
@@ -29,6 +33,17 @@ class AbstractFSClass(ABC):
         pass
 
     @abstractmethod
-    def file_read(self, source_path, source_file,
-                  destination_path, destination_file):
+    def file_read(self, source_path, source_file):
+        pass
+
+    @abstractmethod
+    def file_read_bin(self, source_path, source_file):
+        pass
+
+    @abstractmethod
+    def file_remove(self, file_path, file_name):
+        pass
+
+    @abstractmethod
+    def reinit(self, s3, s3_parameters, bucket, rootdir):
         pass
