@@ -39,14 +39,13 @@ class OsFsClass(AbstractFSClass):
 
     def file_descriptor_copy(self, source_file_descriptor,
                              destination_path, destination_file):
-        source_path, source_file = ntpath.split(source_file_descriptor.name)
-
         self.os_fs.makedirs(destination_path, recreate=True)
 
         destination_base_root = self.fs_root[7:]
 
-        shutil.copyfile('{}/{}'.format(source_path, source_file),
-                        '{}/{}'.format(destination_base_root + '/' + destination_path, destination_file))
+        f = open('{}/{}'.format(destination_base_root + '/' +
+                                destination_path, destination_file), 'wb')
+        f.write(source_file_descriptor.read())
 
     def file_fd(self, file_path, file_name):
         priv_os_fs = open_fs(self.fs_root + file_path)
@@ -76,6 +75,8 @@ class OsFsClass(AbstractFSClass):
     def reinit(self, bucket=None, rootdir=None):
         self.fs_root = 'osfs://'
 
-        self.fs_root = self.fs_root + (rootdir + '/') if rootdir is not None else ''
-        self.fs_root = self.fs_root + (bucket + '/') if bucket is not None else ''
+        self.fs_root = self.fs_root + \
+            (rootdir + '/') if rootdir is not None else ''
+        self.fs_root = self.fs_root + \
+            (bucket + '/') if bucket is not None else ''
         self.os_fs = open_fs(self.fs_root)
